@@ -156,7 +156,6 @@ class Physician(ModelSQL, ModelView):
     'Health Professional'
     _name = 'gnuhealth.physician'
     _description = __doc__
-    _rec_name = 'code'
 
     name = fields.Many2One('party.party', 'Health Professional', required=True,
         domain=[
@@ -181,7 +180,6 @@ class Physician(ModelSQL, ModelView):
                 name = doctor.name.name
                 if doctor.name.lastname:
                     name = doctor.name.lastname + ', ' + name
-
             res[doctor.id] = name
         return res
 
@@ -660,6 +658,17 @@ class PartyPatient (ModelSQL, ModelView):
             res[patient.id] = name
         return res
 
+    def search_rec_name(self, name, clause):
+        ids = []
+        field = None
+        for field in ('name', 'lastname'):
+            ids = self.search([(field,) + clause[1:]], limit=1)
+            if ids:
+                break
+        if ids:
+            return [(field,) + clause[1:]]
+        return [(self._rec_name,) + clause[1:]]
+
 PartyPatient()
 
 
@@ -725,7 +734,6 @@ class PatientData(ModelSQL, ModelView):
     'Patient related information'
     _name = 'gnuhealth.patient'
     _description = __doc__
-    _rec_name = 'identification_code'
 
 # Get the patient age in the following format : 'YEARS MONTHS DAYS'
 # It will calculate the age of the patient while the patient is alive.
@@ -1001,6 +1009,29 @@ class PatientDiseaseInfo(ModelSQL, ModelView):
         self._order.insert(1, ('disease_severity', 'DESC'))
         self._order.insert(2, ('is_infectious', 'DESC'))
         self._order.insert(3, ('diagnosed_date', 'DESC'))
+        self._constraints += [
+            ('validate_disease_period', 'end_date_before_start'),
+            ('validate_treatment_dates', 'end_treatment_date_before_start'),
+            ]
+        self._error_messages.update({
+            'end_date_before_start': 'The HEALED date is BEFORE DIAGNOSED DATE !',
+            'end_treatment_date_before_start': 'The Treatment END DATE is BEFORE the start date!',
+            })
+
+    def validate_disease_period (self, ids):
+        for disease_data in self.browse(ids):
+            if (disease_data.healed_date < disease_data.diagnosed_date):
+                return False
+            else:
+                return True
+
+    def validate_treatment_dates (self, ids):
+        for disease_data in self.browse(ids):
+            if (disease_data.date_stop_treatment < disease_data.date_start_treatment):
+                return False
+            else:
+                return True
+
 
 PatientDiseaseInfo()
 
@@ -1055,6 +1086,21 @@ class Appointment(ModelSQL, ModelView):
 
         return super(Appointment, self).create(values)
 
+    def default_doctor(self):
+        cursor = Transaction().cursor
+        user_obj = Pool().get('res.user')
+        user = user_obj.browse(Transaction().user)
+        login_user_id = int(user.id)
+        cursor.execute('SELECT id FROM party_party WHERE is_doctor=True AND \
+            internal_user = %s LIMIT 1', (login_user_id,))
+        partner_id = cursor.fetchone()
+        if partner_id:
+            cursor = Transaction().cursor
+            cursor.execute('SELECT id FROM gnuhealth_physician WHERE \
+                name = %s LIMIT 1', (partner_id[0],))
+            doctor_id = cursor.fetchone()
+            return int(doctor_id[0])
+
     def default_urgency(self):
         return 'a'
 
@@ -1209,6 +1255,26 @@ class PatientMedication(ModelSQL, ModelView):
     def default_qty(self):
         return 1
 
+    def __init__(self):
+        super(PatientMedication, self).__init__()
+
+        self._constraints += [
+            ('validate_medication_dates', 'end_date_before_start'),
+
+            ]
+
+        self._error_messages.update({
+            'end_date_before_start': 'The Medication END DATE is BEFORE the start date!',
+            })
+
+    def validate_medication_dates (self, ids):
+        for medication_data in self.browse(ids):
+            if (medication_data.end_treatment < medication_data.start_treatment):
+                return False
+            else:
+                return True
+
+
 PatientMedication()
 
 
@@ -1253,10 +1319,14 @@ class PatientVaccination(ModelSQL, ModelView):
         ]
         self._constraints = [
             ('check_vaccine_expiration_date', 'expired_vaccine'),
+            ('validate_next_dose_date', 'next_dose_before_first'),
+
         ]
         self._error_messages.update({
             'expired_vaccine': 'EXPIRED VACCINE. PLEASE INFORM  THE LOCAL '\
                     'HEALTH AUTHORITIES AND DO NOT USE IT !!!',
+            'next_dose_before_first': 'The Vaccine next dose is BEFORE the first one !'
+
         })
 
     def default_date(self):
@@ -1265,6 +1335,13 @@ class PatientVaccination(ModelSQL, ModelView):
     def default_dose(self):
         return 1
 
+    def validate_next_dose_date (self, ids):
+        for vaccine_data in self.browse(ids):
+            if (vaccine_data.next_dose_date < vaccine_data.date):
+                return False
+            else:
+                return True
+
 PatientVaccination()
 
 
@@ -1402,12 +1479,13 @@ class PatientEvaluation(ModelSQL, ModelView):
 
     patient = fields.Many2One('gnuhealth.patient', 'Patient')
     evaluation_date = fields.Many2One('gnuhealth.appointment', 'Appointment',
+        domain=[('patient', '=', Eval('patient'))],
         help='Enter or select the date / ID of the appointment related to'\
         ' this evaluation')
     evaluation_start = fields.DateTime('Start', required=True)
     evaluation_endtime = fields.DateTime('End', required=True)
     next_evaluation = fields.Many2One('gnuhealth.appointment',
-        'Next Appointment')
+        'Next Appointment', domain=[('patient', '=', Eval('patient'))])
     user_id = fields.Many2One('res.user', 'Last Changed by', readonly=True)
     doctor = fields.Many2One('gnuhealth.physician', 'Doctor', readonly=True)
     specialty = fields.Many2One('gnuhealth.specialty', 'Specialty')
@@ -1599,6 +1677,9 @@ class PatientEvaluation(ModelSQL, ModelView):
     def default_loc_motor(self):
         return '6'
 
+    def default_loc(self):
+        return 15
+
     def default_evaluation_type(self):
         return 'pa'
 
@@ -1637,6 +1718,17 @@ class PatientEvaluation(ModelSQL, ModelView):
             whr = 0
         return whr
 
+    def get_rec_name(self, ids, name):
+        if not ids:
+            return {}
+        res = {}
+        for evaluation in self.browse(ids):
+            if evaluation.evaluation_start:
+                name = str(evaluation.evaluation_start)
+            res[evaluation.id] = name
+        return res
+
+
 PatientEvaluation()
 
 
