@@ -19,14 +19,16 @@
 #
 ##############################################################################
 from trytond.model import ModelView, ModelSQL, fields
+from datetime import datetime
 
+from trytond.pyson import Eval, Greater
 
 class DrugsRecreational(ModelSQL, ModelView):
     'Recreational Drug'
     _name = 'gnuhealth.drugs_recreational'
     _description = __doc__
 
-    name = fields.Char('Name', help="Name of the drug")
+    name = fields.Char('Name', translate=True, help="Name of the drug")
     street_name = fields.Char('Street names',
         help="Common name of the drug in street jargon")
 
@@ -172,6 +174,48 @@ class PatientRecreationalDrugs(ModelSQL, ModelView):
 PatientRecreationalDrugs()
 
 
+''' CAGE questionnaire to assess patient dependency to alcohol '''
+
+class PatientCAGE(ModelSQL, ModelView):
+    'Patient CAGE Questionnaire'
+    _name = 'gnuhealth.patient.cage'
+    _description = __doc__
+    
+    name = fields.Many2One('gnuhealth.patient', 'Patient', required=True)
+
+    evaluation_date = fields.DateTime('Date')
+
+    cage_c = fields.Boolean('Hard to Cut down', help='Have you ever felt you needed to Cut down on your drinking ?')
+    cage_a = fields.Boolean('Angry with Critics', help='Have people Annoyed you by criticizing your drinking ?')
+    cage_g = fields.Boolean('Guilt', help='Have you ever felt Guilty about drinking ?')
+    cage_e = fields.Boolean('Eye-opener', help='Have you ever felt you needed a drink first thing in the morning (Eye-opener) to steady your nerves or to get rid of a hangover?')
+    
+    cage_score = fields.Integer('CAGE Score',
+        on_change_with=['cage_c','cage_a','cage_g','cage_e'])
+    
+    
+    def on_change_with_cage_score(self, vals):
+        total = 0
+
+        if vals.get('cage_c'):
+            total=total + 1
+        if vals.get('cage_a'):
+            total=total + 1
+        if vals.get('cage_g'):
+            total=total + 1
+        if vals.get('cage_e'):
+            total=total + 1
+
+        return total
+
+    def default_evaluation_date(self):
+        return datetime.now()
+
+    def default_cage_score(self):
+        return 0
+        
+PatientCAGE()
+
 class MedicalPatient(ModelSQL, ModelView):
     _name = 'gnuhealth.patient'
 
@@ -300,4 +344,7 @@ class MedicalPatient(ModelSQL, ModelView):
 
     sexuality_info = fields.Text('Extra Information')
 
+    cage = fields.One2Many('gnuhealth.patient.cage',
+        'name', 'CAGE')
+
 MedicalPatient()
